Enum Eocs
#[repr(u8)]pub enum Eocs {
EachSequence = 0,
EachConversion = 1,
}Variants
EachSequence = 0
The EOC bit is set at the end of each sequence of regular conversions
EachConversion = 1
The EOC bit is set at the end of each regular conversion
Implementations